Index: main/features.c
===================================================================
--- main/features.c	(revision 291903)
+++ main/features.c	(working copy)
@@ -1481,9 +1481,12 @@
 		}
 	}
 
+	ast_log(LOG_NOTICE, "doing a feature_request_and_dial for %s and %s\n", transferer->name, transferee->name);
 	newchan = feature_request_and_dial(transferer, transferee, "Local", ast_best_codec(transferer->nativeformats),
 		xferto, atxfernoanswertimeout, &outstate, transferer->cid.cid_num, transferer->cid.cid_name, 1, transferer->language);
 
+	ast_log(LOG_NOTICE, "done with feature_request_and_dial, got %s\n", newchan ? newchan->name : "nothing");
+
 	if (!ast_check_hangup(transferer)) {
 		int hangup_dont = 0;
 
@@ -1515,6 +1518,7 @@
 		if (ast_test_flag(chan, AST_FLAG_BRIDGE_HANGUP_DONT)) {
 			hangup_dont = 1;
 		}
+		ast_log(LOG_NOTICE, "going to bridge %s and %s for attended transfer\n", transferer->name, newchan->name);
 		res = ast_bridge_call(transferer, newchan, &bconfig);
 		if (hangup_dont) {
 			ast_set_flag(chan, AST_FLAG_BRIDGE_HANGUP_DONT);
@@ -1598,8 +1602,10 @@
 			tobj->bconfig.end_bridge_callback_data_fixup(&tobj->bconfig, tobj->peer, tobj->chan);
 		}
 
+		ast_log(LOG_NOTICE, "Going to play transfer sound.\n");
 		if (ast_stream_and_wait(newchan, xfersound, ""))
 			ast_log(LOG_WARNING, "Failed to play transfer sound!\n");
+		ast_log(LOG_NOTICE, "finishing up attended transfer by bridging %s and %s\n", xferchan->name, newchan->name);
 		bridge_call_thread_launch(tobj);
 		return -1;      /* XXX meaning the channel is bridged ? */
 	} else if (!ast_check_hangup(transferee)) {
@@ -2284,6 +2290,7 @@
 			}
 			f = ast_read(chan);
 			if (f == NULL) { /*doh! where'd he go?*/
+				ast_log(LOG_NOTICE, "error reading from %s", chan->name);
 				state = AST_CONTROL_HANGUP;
 				res = 0;
 				break;
@@ -2303,6 +2310,7 @@
 					break;
 				} else if (f->subclass == AST_CONTROL_ANSWER) {
 					/* This is what we are hoping for */
+					ast_log(LOG_NOTICE, "got answer on %s\n", chan->name);
 					state = f->subclass;
 					ast_frfree(f);
 					f = NULL;
@@ -2319,6 +2327,7 @@
 		} else if (caller && (active_channel == caller)) {
 			f = ast_read(caller);
 			if (f == NULL) { /*doh! where'd he go?*/
+				ast_log(LOG_NOTICE, "error reading from caller %s\n", chan->name);
 				if (!igncallerstate) {
 					if (ast_check_hangup(caller) && !ast_check_hangup(chan)) {
 						/* make this a blind transfer */
Index: main/file.c
===================================================================
--- main/file.c	(revision 291903)
+++ main/file.c	(working copy)
@@ -704,6 +704,7 @@
 	}
 
 	if (!(fr = s->fmt->read(s, whennext))) {
+		ast_log(LOG_NOTICE, "fmt->read is trying to tell us something\n");
 		return NULL;
 	}
 
@@ -779,6 +780,7 @@
 	return FSREAD_SUCCESS_SCHED;
 
 return_failure:
+	ast_log(LOG_NOTICE, "I think we are finished streaming\n");
 	s->owner->streamid = -1;
 	ast_settimeout(s->owner, 0, NULL, NULL);
 	return FSREAD_FAILURE;
@@ -1203,9 +1205,13 @@
 		ms = ast_sched_wait(c->sched);
 
 		if (ms < 0 && !c->timingfunc) {
+			ast_log(LOG_NOTICE, "done streaming file\n");
 			ast_stopstream(c);
 			break;
+		} else {
+			ast_log(LOG_NOTICE, "still streaming, ms = %d, c->timingfunc = %p\n", ms, c->timingfunc);
 		}
+
 		if (ms < 0)
 			ms = 1000;
 		if (cmdfd < 0) {
